@@ -30,7 +30,7 @@ describe 'tripleo::profile::base::keystone' do
       :oslomsg_notify_username => 'keystone2',
       :oslomsg_notify_password => 'baa',
       :oslomsg_notify_port     => '5678',
-      :memcached_hosts         => [ '192.168.0.3', '192.168.0.4', '192.168.0.5' ],
+      :memcached_ips           => [ '192.168.0.3', '192.168.0.4', '192.168.0.5' ],
     }
   end
 
@@ -51,7 +51,7 @@ describe 'tripleo::profile::base::keystone' do
         is_expected.to_not contain_class('keystone::security_compliance')
         is_expected.to_not contain_class('keystone::ldap_backend')
         is_expected.to_not contain_class('keystone::federation::openidc')
-        is_expected.to_not contain_class('keystone::cron::token_flush')
+        is_expected.to_not contain_class('keystone::cron::trust_flush')
       end
     end
 
@@ -74,7 +74,7 @@ describe 'tripleo::profile::base::keystone' do
         is_expected.to contain_class('keystone::security_compliance')
         is_expected.to_not contain_class('keystone::ldap_backend')
         is_expected.to_not contain_class('keystone::federation::openidc')
-        is_expected.to_not contain_class('keystone::cron::token_flush')
+        is_expected.to_not contain_class('keystone::cron::trust_flush')
       end
     end
 
@@ -98,7 +98,7 @@ describe 'tripleo::profile::base::keystone' do
         is_expected.to_not contain_class('keystone::security_compliance')
         is_expected.to_not contain_class('keystone::ldap_backend')
         is_expected.to_not contain_class('keystone::federation::openidc')
-        is_expected.to_not contain_class('keystone::cron::token_flush')
+        is_expected.to_not contain_class('keystone::cron::trust_flush')
       end
     end
 
@@ -121,7 +121,7 @@ describe 'tripleo::profile::base::keystone' do
         is_expected.to contain_class('keystone::security_compliance')
         is_expected.to_not contain_class('keystone::ldap_backend')
         is_expected.to_not contain_class('keystone::federation::openidc')
-        is_expected.to_not contain_class('keystone::cron::token_flush')
+        is_expected.to_not contain_class('keystone::cron::trust_flush')
       end
     end
 
@@ -148,7 +148,7 @@ describe 'tripleo::profile::base::keystone' do
         is_expected.to contain_class('keystone::security_compliance')
         is_expected.to_not contain_class('keystone::ldap_backend')
         is_expected.to_not contain_class('keystone::federation::openidc')
-        is_expected.to_not contain_class('keystone::cron::token_flush')
+        is_expected.to_not contain_class('keystone::cron::trust_flush')
       end
     end
 
@@ -162,8 +162,8 @@ describe 'tripleo::profile::base::keystone' do
         )
       end
 
-      it 'should not trigger token_flush configuration' do
-        is_expected.to_not contain_class('keystone::cron::token_flush')
+      it 'should not trigger purge configuration' do
+        is_expected.to_not contain_class('keystone::cron::trust_flush')
       end
     end
 
@@ -177,8 +177,8 @@ describe 'tripleo::profile::base::keystone' do
         )
       end
 
-      it 'should trigger token_flush configuration' do
-        is_expected.to contain_class('keystone::cron::token_flush')
+      it 'should trigger purge configuration' do
+        is_expected.to contain_class('keystone::cron::trust_flush')
       end
     end
   end
